#
# spec file for package govc
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           govc
Version:        0.36.3
Release:        1.1
Summary:        vSphere CLI built on top of govmomi
License:        Apache-2.0
URL:            https://github.com/vmware/govmomi
Source:         govmomi-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.19

%description
The CLI is designed to be a user friendly CLI alternative to the GUI and well suited for automation tasks. It also acts as a test harness for the govmomi APIs and provides working examples of how to use the APIs.

%prep
%autosetup -p 1 -a 1 -n govmomi-%{version}

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X github.com/vmware/govmomi/govc/flags.BuildVersion=%{version} \
   -X github.com/vmware/govmomi/govc/flags.BuildCommit=v%{version} \
   -X github.com/vmware/govmomi/govc/flags.BuildDate=$BUILD_DATE" \
   -o bin/govc ./govc/main.go

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE.txt
%{_bindir}/%{name}

%changelog
* Wed Apr  3 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.3:
  * chore: Update version.go for v0.36.3
  * Remove deprecation for task.Wait and task.WaitForResult
* Sat Mar 30 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.2:
  * chore: Update version.go for v0.36.2
  * govc: snapshot.tree json output to stdout
  * fix: endpoint url to bypass lookup service if envoy sidecar
    enabled
  * api: Add Downloadendpoint field in the library item file struct
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.1:
  * chore: Update version.go for v0.36.1
  * Add support for SHA256 thumbprint based vCenter authentication
  * fix: lookup client to use envoy sidecar url if enabled
* Sat Mar 16 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.36.0:
  * chore: Update version.go for v0.36.0
  * Updating CONTRIBUTORS
  * fix: vcsim Fetch method causes runtime panic when property is
    not set
  * Add APIs for vLCM enablement on a cluster and base ESXi image
    selection
  * chore: bump Go versions
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to
    1.9.0
  * Add API for vLCM - offline depots and cluster baseline images
  * chore: Better support for ESXi & HW versions
  * vcsim: Enhanced sim support for upgrade VM
  * fix: Update summary.config.hwVersion in simulator
  * test fixes
  * fix: govc: use session KeepAlive in library.export command
  * Add service locator to CNS RelocateVolume spec
  * Add  "AggregatedSnapshotCapacityInMb" to
    CnsSnapshotCreateResult and CnsSnapshotDeleteResult.
* Mon Feb 12 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.35.0:
  * chore: Update version.go for v0.35.0
  * docs: update release doc
  * chore: update CONTRIBUTORS
  * govc: json tag camelCase fixes
  * Add "AggregatedSnapshotCapacityInMb" to cnstype.
  * add -json to snapshot.tree
  * build(deps): bump nokogiri from 1.14.3 to 1.16.2 in /gen
  * api: Sim vm config.changeVersion & config.modified
  * build(deps): bump peter-evans/create-pull-request from 5 to 6
  * Re-enable PC updates for indexed properties
  * build(deps): bump andstor/file-existence-action from 2 to 3
  * build(deps): bump peter-evans/create-or-update-comment from 3
    to 4
  * Add new "UsedCapacityInMb" in struct "CnsBlockBackingDetails"
  * build(deps): bump github.com/google/uuid from 1.5.0 to 1.6.0
  * build(deps): bump actions/cache from 3 to 4
  * Self identify the executable making calls to vCenter
  * api: WaitForUpdatesEx & DestroyPropertyFilter
  * Changes to fix xml tag used for SnapshotId
  * vcsim: Fix -method-delay option to update task states
  * Fixes Missing Tags in AttachedTags
  * Changes to add CNS fault CnsSnapshotCreatedFault
  * build(deps): bump actions/upload-artifact from 3 to 4
  * build(deps): bump github/codeql-action from 2 to 3
  * build(deps): bump github.com/google/uuid from 1.4.0 to 1.5.0
  * build(deps): bump chuhlomin/render-template from 1.8 to 1.9
* Sat Jan 20 2024 Johannes Kastl <opensuse_buildservice@ojkastl.de>
- new package govc: vSphere CLI written in go
